@@ -1,12 +1,14 @@
 import logging
-__version__ = '1.1.3'
+__version__ = '1.2.4'
 
-gearauthsite = "http://gearauth.netpie.io:8080"
-gearauthrequesttokenendpoint = gearauthsite+"/oauth/request_token"
-gearauthaccesstokenendpoint = gearauthsite+"/oauth/access_token"
+gearauthsite = "http://ga.netpie.io:8080"
+gearauthrequesttokenendpoint = gearauthsite+"/api/rtoken"
+gearauthaccesstokenendpoint = gearauthsite+"/api/atoken"
 
+mgrev = "PY11k"
 gearkey = None
 gearsecret = None
+gearalias = None
 appid = None
 gearname = None
 accesstoken = None
@@ -16,4 +18,4 @@ scope = ""
 gearexaddress = None
 gearexport = None
 mqtt_client = None
-logger = logging.getLogger("python-microgear")
\ No newline at end of file
+logger = logging.getLogger("python-microgear")
